@@ -2,7 +2,7 @@
 
 package Games::Nintendo::Mario::SMB;
 
-our $VERSION = '0.10';
+our $VERSION = '0.200';
 
 use base qw(Games::Nintendo::Mario);
 
@@ -14,24 +14,24 @@ sub _states { qw[normal super fire] }
 sub _items  { qw[mushroom flower] }
 
 sub _goto_hash { 
-	{
-		damage => {
-			normal	=> 'dead',
-			_else	=> 'normal'
-		},
-		mushroom => {
-			flower	=> 'fire',
-			_else	=> 'super',
-		},
-		flower => {
-			normal	=> 'super',
-			_else	=> 'fire'
-		}
-	}
+  {
+    damage => {
+      normal => 'dead',
+      _else  => 'normal'
+    },
+    mushroom => {
+      fire  => 'fire',
+      _else => 'super',
+    },
+    flower => {
+      normal => 'super',
+      _else  => 'fire'
+    }
+  }
 }
 
 sub games {
-	return ('Super Mario Bros.');
+  return ('Super Mario Bros.');
 }
 
 "It's-a me!  Mario!";
@@ -89,7 +89,7 @@ Ricardo SIGNES E<lt>rjbs@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2003 by Ricardo Signes E<lt>rjbs@cpan.orgE<gt>
+Copyright 2003 by Ricardo SIGNES E<lt>rjbs@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
